namespace elm { 
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Hover::target_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_hover_target_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hover::target_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type target) const
{
    ::elm_obj_hover_target_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(target));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Hover::best_content_location_get( ::efl::eolian::in_traits<Elm_Hover_Axis>::type pref_axis) const
{
   const char * __return_value =  ::elm_obj_hover_best_content_location_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Hover_Axis,  ::efl::eolian::in_traits<Elm_Hover_Axis>::type>(pref_axis));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hover::dismiss() const
{
    ::elm_obj_hover_dismiss(this->_eo_ptr());
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Hover::target_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_hover_target_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hover::target_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type target) const
{
    ::elm_obj_hover_target_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(target));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Hover::best_content_location_get( ::efl::eolian::in_traits<Elm_Hover_Axis>::type pref_axis) const
{
   const char * __return_value =  ::elm_obj_hover_best_content_location_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Hover_Axis,  ::efl::eolian::in_traits<Elm_Hover_Axis>::type>(pref_axis));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Hover::dismiss() const
{
    ::elm_obj_hover_dismiss(this->_eo_ptr());
}
inline elm::Hover::operator ::elm::Hover() const { return *static_cast< ::elm::Hover const*>(static_cast<void const*>(this)); }
inline elm::Hover::operator ::elm::Hover&() { return *static_cast< ::elm::Hover*>(static_cast<void*>(this)); }
inline elm::Hover::operator ::elm::Hover const&() const { return *static_cast< ::elm::Hover const*>(static_cast<void const*>(this)); }
} }

